################################################################################
# Supplement B for ``Regularization and Model Selection with
# Categorical Predictors and Effect Modifiers in Generalized Linear Models''
# Margret-Ruth Oelker, Jan Gertheiss and Gerhard Tutz
# 2013, May 23th

################################################################################
# R-code for Section 5: Acceptance of Boar Meat

# functions
  library(gvcm.cat)

# data
  load("boar.data.RData")
  # comments on the coding of covariates
  #   - taste:     0 = no, 1 = yes
  #   - product:   1 = pork with label pork
  #                2 = pork with label boar
  #                3 = boar with label pork
  #                4 = boar with label boar
  #   - know.lab:  0 = no, 1 = yes
  #   - gender:    levels "f" for female and "m" for male, reference: female
  #   - contact:   0 = some contact, 1 = no contact
  #   - age:       numeric, in years
  #   - smoker:    0 = no, 1 = yes
  #   - sick:      0 = no, 1 = yes

# model
  f  <- taste ~ v(1, product) + v(know.lab, product) + v(gender, product) + v(contact, product) +
          v(age, product) + v(smoker, product) + v(sick, product)
  m <- gvcm.cat(f, data, family=binomial(), plot=TRUE, x=TRUE,
        control=cat_control(adapted.weights=TRUE, lambda.upper=10))
  plot(m)
  plot(m, type="score")
  summary(m)

  ma <- gvcm.cat(f, data, family=binomial(), plot=TRUE, method="AIC",
        control=cat_control(adapted.weights=TRUE, lambda.upper=10))
  summary(ma)

  mb <- gvcm.cat(f, data, family=binomial(), plot=TRUE, method="BIC",
        control=cat_control(adapted.weights=TRUE, lambda.upper=10))
  summary(mb)


